@@ -1,4 +1,4 @@
-/* Copyright (C) 2001-2023 Artifex Software, Inc.
+/* Copyright (C) 2001-2024 Artifex Software, Inc.
    All Rights Reserved.
 
    This software is provided AS-IS with no warranty, either express or
@@ -79,6 +79,8 @@ typedef struct gx_saved_page_s {
     char bfname[gp_file_name_sizeof];	/* block file name */
     const clist_io_procs_t *io_procs;
     uint tile_cache_size;	/* size of tile cache */
+    size_t line_ptrs_offset;
+    int num_planar_planes;
     int64_t bfile_end_pos;		/* ftell at end of bfile */
     gx_band_params_t band_params;  /* parameters used when writing band list */
                                 /* (actual values, no 0s) */
@@ -261,11 +263,11 @@ typedef struct gx_device_clist_common_s {
     gx_device_clist_common_members;
 } gx_device_clist_common;
 
-#define clist_band_height(cldev) ((cldev)->page_band_height)
-#define clist_cfname(cldev) ((cldev)->page_cfname)
-#define clist_cfile(cldev) ((cldev)->page_cfile)
-#define clist_bfname(cldev) ((cldev)->page_bfname)
-#define clist_bfile(cldev) ((cldev)->page_bfile)
+#define clist_band_height(cldev) ((cldev)->page_info.band_params.BandHeight)
+#define clist_cfname(cldev) ((cldev)->page_info.cfname)
+#define clist_cfile(cldev) ((cldev)->page_info.cfile)
+#define clist_bfname(cldev) ((cldev)->page_info.bfname)
+#define clist_bfile(cldev) ((cldev)->page_info.bfile)
 
 /* Define the length of the longest dash pattern we are willing to store. */
 /* (Strokes with longer patterns are converted to fills.) */
