@@ -1,4 +1,4 @@
-/* Copyright (C) 2001-2020 Artifex Software, Inc.
+/* Copyright (C) 2001-2023 Artifex Software, Inc.
    All Rights Reserved.
 
    This software is provided AS-IS with no warranty, either express or
@@ -9,8 +9,8 @@
    of the license contained in the file LICENSE in this distribution.
 
    Refer to licensing information at http://www.artifex.com or contact
-   Artifex Software, Inc.,  1305 Grant Avenue - Suite 200, Novato,
-   CA 94945, U.S.A., +1(415)492-9861, for further information.
+   Artifex Software, Inc.,  39 Mesa Street, Suite 108A, San Francisco,
+   CA 94129, USA, for further information.
 */
 
 
@@ -221,10 +221,8 @@ pdf_font_descriptor_alloc(gx_device_pdf *pdev, pdf_font_descriptor_t **ppfd,
     return 0;
 }
 
-int pdf_font_descriptor_free(gx_device_pdf *pdev, pdf_resource_t *pres)
+int pdf_base_font_free(gx_device_pdf *pdev, pdf_base_font_t *pbfont)
 {
-    pdf_font_descriptor_t *pfd = (pdf_font_descriptor_t *)pres;
-    pdf_base_font_t *pbfont = pfd->base_font;
     gs_font *copied = NULL, *complete = NULL;
 
     if (pbfont) {
@@ -239,14 +237,27 @@ int pdf_font_descriptor_free(gx_device_pdf *pdev, pdf_resource_t *pres)
         gs_free_copied_font(copied);
 
     if (pbfont) {
+        if (pbfont->CIDSet)
+            gs_free_object(pdev->pdf_memory, pbfont->CIDSet, "Free base font CIDSet from FontDescriptor)");
+
         if (pbfont->font_name.size) {
             gs_free_string(pdev->pdf_memory, pbfont->font_name.data, pbfont->font_name.size, "Free BaseFont FontName string");
             pbfont->font_name.data = (byte *)0L;
             pbfont->font_name.size = 0;
         }
-        gs_free_object(cos_object_memory(pres->object), pbfont, "Free base font from FontDescriptor)");
-        pfd->base_font = 0;
+        gs_free_object(pdev->pdf_memory, pbfont, "Free base font from FontDescriptor)");
     }
+    return 0;
+}
+
+int pdf_font_descriptor_free(gx_device_pdf *pdev, pdf_resource_t *pres)
+{
+    pdf_font_descriptor_t *pfd = (pdf_font_descriptor_t *)pres;
+    pdf_base_font_t *pbfont = pfd->base_font;
+
+    pdf_base_font_free(pdev, pbfont);
+    pfd->base_font = 0;
+
     if (pres->object) {
         gs_free_object(pdev->pdf_memory, pres->object, "free FontDescriptor object");
         pres->object = NULL;
