@@ -249,14 +249,18 @@ int pdfi_repair_file(pdf_context *ctx)
                                             code = pdfi_read_bare_keyword(ctx, ctx->main_stream);
                                             if (code == gs_error_VMerror || code == gs_error_ioerror)
                                                 goto exit;
-                                            if (code == TOKEN_ENDOBJ || code == TOKEN_INVALID_KEY) {
-                                                code = pdfi_repair_add_object(ctx, object_num, generation_num, offset);
-                                                if (code == gs_error_VMerror || code == gs_error_ioerror)
-                                                    goto exit;
-                                                break;
+                                            if (code < 0) {
+                                                /* Something went wrong and we couldn't read a token, consume one byte and retry */
+                                                (void)pdfi_read_byte(ctx, ctx->main_stream);
+                                            } else {
+                                                if (code == TOKEN_ENDOBJ || code == TOKEN_INVALID_KEY) {
+                                                    code = pdfi_repair_add_object(ctx, object_num, generation_num, offset);
+                                                    if (code == gs_error_VMerror || code == gs_error_ioerror)
+                                                        goto exit;
+                                                    break;
+                                                }
                                             }
                                         } while(ctx->main_stream->eof == false);
-
                                         pdfi_clearstack(ctx);
                                         break;
                                     } else {
